<?xml version="1.0" encoding="UTF-8"?>

<!--
  ===========================================================================

    KOPETE STYLE : Clear

    AUTHOR NAME  : Francois Chazal
    AUTHOR EMAIL : chazal_f@epita.fr

    DISTRIBUTION LICENCE :

      This program is free software; you can redistribute it and/or modify
     it under the terms of the  GNU General Public License as published by
     the  Free  Software  Foundation ; either version 2 of the License, or
     (at your option) any later version.

  ===========================================================================
-->

<?Kopete Flag:TransformAllMessages?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html"/>

  <xsl:param name="appdata"/>
  <!-- if the previous statement doesn't work try this one :
  <xsl:variable name="appdata">COMPLETE_PATH_TO_THE_DATA_DIRECTORY</xsl:variable>
  -->

  <xsl:variable name="data-path">file:///<xsl:value-of select="$appdata"/>Clear/</xsl:variable>

  <!-- could be defined if no personal avatar shows up automatically -->
  <xsl:variable name="user-photo">null</xsl:variable>



  <!-- Definition of the document ========================================-->

  <xsl:template match="document">
    <xsl:variable name="messages" select="message"/>

    <div class="KopeteMessage">
      <xsl:attribute name="style">
        letter-spacing: 1px;
        font-family: arial;
        font-size: 11px;
        padding: 5px;
      </xsl:attribute>

      <xsl:for-each select="message">
        <xsl:call-template name="process_message">
          <xsl:with-param name="messages" select="$messages"/>
        </xsl:call-template>
      </xsl:for-each>

    </div>
  </xsl:template>



  <!-- Messages processing =================================================-->

  <xsl:template name="process_message">
    <xsl:param name="messages"/>


    <!-- Variables definition = = = = = = = = = = = = = = = = = = = = = = = -->

    <xsl:variable name="position" select="position()"/>

    <xsl:variable name="next" select="$messages[$position + 1]"/>
    <xsl:variable name="next_author" select="$next/from/contact/@contactId"/>

    <xsl:variable name="current" select="$messages[$position]"/>
    <xsl:variable name="current_author" select="$current/from/contact/@contactId"/>

    <xsl:variable name="previous" select="$messages[$position - 1]"/>
    <xsl:variable name="previous_author" select="$previous/from/contact/@contactId"/>


    <!-- Message group definition = = = = = = = = = = = = = = = = = = = = = -->

    <div class="message">

    <xsl:choose>

      <!-- Incoming or Outgoing messages  - - - - - - - - - - - - - - - - - -->

      <xsl:when test="((@route='inbound') or (@route='outbound')) and (@type='normal')">
        <xsl:if test="not($previous_author = $current_author) or (@importance='2')">

          <xsl:attribute name="style">
            margin-left: 6px;
            margin-right: 6px;
            margin-bottom: 10px;
          </xsl:attribute>

          <!-- Defines the photo source - - - - - - - - - - - - - - - - - - -->

          <xsl:variable name="photo-src">
            <xsl:choose>
              <xsl:when test="from/contact/@userPhoto">
                data:image/png;base64,<xsl:value-of select="from/contact/@userPhoto"/>
              </xsl:when>

              <xsl:when test="@route='outbound' and not($user-photo='null')">
                <xsl:value-of select="$user-photo"/>
              </xsl:when>

              <xsl:otherwise>null</xsl:otherwise>
            </xsl:choose>
          </xsl:variable>

          <!-- Header of the message  - - - - - - - - - - - - - - - - - - - -->

          <div class="message_header">
            <xsl:attribute name="style">
              background: url(<xsl:value-of select="$data-path"/>header-<xsl:value-of select="@route"/>-background.png) repeat-x;

              <xsl:if test="@route='inbound'">background-color: #c9d9f0;</xsl:if>
              <xsl:if test="@route='outbound'">background-color: #e1e1e1;</xsl:if>
            </xsl:attribute>

            <div class="message_header1">
              <xsl:attribute name="style">
                background: url(<xsl:value-of select="$data-path"/>header-<xsl:value-of select="@route"/>-left.png) no-repeat top left;
              </xsl:attribute>

              <div id="message_header2">
                <xsl:attribute name="style">
                  background: url(<xsl:value-of select="$data-path"/>header-<xsl:value-of select="@route"/>-right.png) no-repeat top right;
                  padding-right: 4px;
                  padding-left: 4px;
                  vertical-align: middle;
                  line-height: 20px;
                  height: 20px;
                </xsl:attribute>

                <span class="sender_name">
                  <xsl:attribute name="style">
                    position: absolute;
                    text-align: left; font-size: 10px; font-weight: bold;
                    padding-right: 20px;
                    padding-left: 20px;
                    overflow: hidden;
                    height: 20px;

                    <xsl:if test="@route='inbound'">
                      background: url(<xsl:value-of select="$data-path"/>icon-you.png) no-repeat center left;
                      color: #567199;
                    </xsl:if>
                    <xsl:if test="@route='outbound'">
                      background: url(<xsl:value-of select="$data-path"/>icon-me.png) no-repeat center left;
                      color: #707070;
                    </xsl:if>

                    <xsl:if test="@importance='2'">
                      background: url(<xsl:value-of select="$data-path"/>icon-highlighted.png) no-repeat center left;
                    </xsl:if>
                  </xsl:attribute>

                  <kopete-i18n>%FROM_METACONTACT_DISPLAYNAME%</kopete-i18n>
                </span>

                <span class="sending_time">
                  <xsl:attribute name="style">
                    background: url(<xsl:value-of select="$data-path"/>icon-time.png) no-repeat center right;
                    position: relative;
                    padding-right: 18px;
                    padding-left: 5px;
                    text-align: right;
                    font-weight: bold;
                    font-size: 10px;
                    float: right;
                    z-index: 1;

                    <xsl:if test="@route='inbound'">color: #567199;</xsl:if>
                    <xsl:if test="@route='outbound'">color: #707070;</xsl:if>
                  </xsl:attribute>

                  <xsl:value-of select="@time"/>
                </span>
              </div>
            </div>
          </div>

          <!-- Contents of the message  - - - - - - - - - - - - - - - - - - -->

          <div class="message_body">
            <xsl:attribute name="style">
                background: url(<xsl:value-of select="$data-path"/>body-background.png) repeat-x top;

                <xsl:if test="@route='inbound'">
                  background-color: #f5f6fa;
                  border-bottom: 1px solid #c9d9f0;
                </xsl:if>
                <xsl:if test="@route='outbound'">
                  background-color: #f9f9f9;
                  border-bottom: 1px solid #e1e1e1;
                </xsl:if>
            </xsl:attribute>

            <div class="message_body2">
              <xsl:attribute name="style">
                background: url(<xsl:value-of select="$data-path"/>body-<xsl:value-of select="@route"/>-left.png) no-repeat top left;
              </xsl:attribute>

              <div class="message_body3">
                <xsl:attribute name="style">
                  background: url(<xsl:value-of select="$data-path"/>body-<xsl:value-of select="@route"/>-right.png) no-repeat top right;
                  padding: 5px;

                  <xsl:if test="not($photo-src='null')">
                    min-height: 55px;
                  </xsl:if>
                </xsl:attribute>

                <xsl:if test="not($photo-src='null')">
                  <div class="message_avatar">
                    <xsl:attribute name="style">
                      float: left;
                      width: 60px;
                      height: 52px;
                      margin: -1px;
                      padding-top: 6px;
                      padding-left: 6px;
                      background: url(<xsl:value-of select="$data-path"/>body-<xsl:value-of select="@route"/>-avatar.png) no-repeat top left;
                    </xsl:attribute>

                    <img width="46" height="46">
                      <xsl:attribute name="src">
                        <xsl:value-of select="$photo-src"/>
                      </xsl:attribute>
                    </img>
                  </div>
                </xsl:if>

                <xsl:call-template name="render_messages">
                  <xsl:with-param name="direction" select="@direction"/>
                  <xsl:with-param name="messages" select="$messages"/>
                  <xsl:with-param name="position" select="$position"/>
                  <xsl:with-param name="author" select="$current_author"/>
                  <xsl:with-param name="arrow" select="concat($data-path,'body-',@route,'-arrow.png')"/>
                </xsl:call-template>
              </div>
            </div>
          </div>

          <!-- Footer of the message  - - - - - - - - - - - - - - - - - - - -->

          <div class="message_footer">
            <xsl:attribute name="style">
              background: url(<xsl:value-of select="$data-path"/>footer-<xsl:value-of select="@route"/>-background.png) repeat-x;
              background-color: #ffffff;
            </xsl:attribute>

            <div class="message_footer1">
              <xsl:attribute name="style">
                background: url(<xsl:value-of select="$data-path"/>footer-<xsl:value-of select="@route"/>-left.png) no-repeat top left;
              </xsl:attribute>

              <div id="message_footer2">
                <xsl:attribute name="style">
                  background: url(<xsl:value-of select="$data-path"/>footer-<xsl:value-of select="@route"/>-right.png) no-repeat top right;
                  height: 9px;
                </xsl:attribute>
              </div>
            </div>
          </div>

        </xsl:if>
      </xsl:when>


      <!-- Action or System messages  - - - - - - - - - - - - - - - - - - - -->

      <xsl:when test="(@route='internal') or (@type='action')">

        <xsl:attribute name="style">
          background: #fafafa;
          margin-left: 6px;
          margin-right: 6px;
          padding-left: 3px;
          padding-right: 3px;
          margin-bottom: 10px;
          border: 1px solid #e0e0e0;
          vertical-align: middle;
          line-height: 20px;
          height: 20px;
        </xsl:attribute>

        <span class="message-body">
          <xsl:attribute name="style">
            position: absolute;

            <!-- Internal message -->
            <xsl:if test="@route='internal'">
              background: url(<xsl:value-of select="$data-path"/>icon-internal.png) no-repeat center left;
            </xsl:if>

            <!-- Action message -->
            <xsl:if test="@type='action'">
              background: url(<xsl:value-of select="$data-path"/>icon-action.png) no-repeat center left;
            </xsl:if>

            text-align: left; font-size: 10px; font-weight: bold; color: #808080;
            padding-right: 20px;
            padding-left: 20px;
            overflow: hidden;
            height: 20px;
            float: left;
          </xsl:attribute>

          <xsl:if test="@type='action'">
            <kopete-i18n>%FROM_METACONTACT_DISPLAYNAME%</kopete-i18n><xsl:text> </xsl:text>
          </xsl:if>

          <xsl:value-of disable-output-escaping="yes" select="body"/>
        </span>

        <span class="message-time">
          <xsl:attribute name="style">
            position: relative;
            background: url(<xsl:value-of select="$data-path"/>icon-time.png) no-repeat center right;
            text-align: right; font-size: 10px; font-weight: bold; color: #808080;
            padding-right: 18px;
            padding-left: 5px;
            float: right;
            z-index: 1;
          </xsl:attribute>

          <xsl:value-of select="@time"/>
        </span>
      </xsl:when>

    </xsl:choose>
    </div>
  </xsl:template>




  <!-- Other messages rendering ============================================-->

  <xsl:template name="render_messages">
    <xsl:param name="direction"/>
    <xsl:param name="messages"/>
    <xsl:param name="position"/>
    <xsl:param name="author"/>
    <xsl:param name="arrow"/>

    <xsl:variable name="current" select="$messages[$position]"/>
    <xsl:variable name="current_author" select="$current/from/contact/@contactId"/>
    <xsl:variable name="current_direction" select="$current/@direction"/>

    <xsl:if test="($current_author = $author) and ($current_direction = $direction)">

      <xsl:for-each select="$current">
        <div>
          <xsl:attribute name="style">
            overflow: auto;
            padding-left: 2px;
            padding-right: 2px;

            <xsl:if test="body/@font">
              font:<xsl:value-of select="body/@font"/>;
            </xsl:if>
            <xsl:if test="body/@color">
              color:<xsl:value-of select="body/@color"/>;
            </xsl:if>
            <xsl:if test="body/@bgcolor">
              background-color:<xsl:value-of select="body/@bgcolor"/>;
            </xsl:if>
          </xsl:attribute>

          <xsl:if test="@importance='2'">
            <xsl:attribute name="class">
              <xsl:text>highlight</xsl:text>
            </xsl:attribute>
          </xsl:if>

          <img src="{$arrow}" style="padding-bottom: 2px; vertical-align: middle;"/>
          <xsl:value-of disable-output-escaping="yes" select="body"/>
        </div>
      </xsl:for-each>

      <xsl:call-template name="render_messages">
        <xsl:with-param name="direction" select="$direction"/>
        <xsl:with-param name="messages" select="$messages"/>
        <xsl:with-param name="position" select="$position + 1"/>
        <xsl:with-param name="author" select="$author"/>
        <xsl:with-param name="arrow" select="$arrow"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
